@@ -28,9 +28,12 @@ sub call {
 
     if ($trace && ($caught || ($self->force && ref $res eq 'ARRAY' && $res->[0] == 500)) ) {
         my $text = trace_as_string($trace);
+        my $html = $trace->as_html;
+        $env->{'plack.stacktrace.text'} = $text;
+        $env->{'plack.stacktrace.html'} = $html;
         $env->{'psgi.errors'}->print($text) unless $self->no_print_errors;
         if (($env->{HTTP_ACCEPT} || '*/*') =~ /html/) {
-            $res = [500, ['Content-Type' => 'text/html; charset=utf-8'], [ utf8_safe($trace->as_html) ]];
+            $res = [500, ['Content-Type' => 'text/html; charset=utf-8'], [ utf8_safe($html) ]];
         } else {
             $res = [500, ['Content-Type' => 'text/plain; charset=utf-8'], [ utf8_safe($text) ]];
         }
@@ -90,7 +93,10 @@ Plack::Middleware::StackTrace - Displays stack trace when your app dies
 =head1 DESCRIPTION
 
 This middleware catches exceptions (run-time errors) happening in your
-application and displays nice stack trace screen.
+application and displays nice stack trace screen. The stack trace is
+also stored in the environment as a plaintext and HTML under the key
+C<plack.stacktrace.text> and C<plack.stacktrace.html> respectively, so
+that middleware futher up the stack can reference it.
 
 This middleware is enabled by default when you run L<plackup> in the
 default I<development> mode.
